==> openshift-model-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/AppliedClusterResourceQuotaListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface AppliedClusterResourceQuotaListFluent<A extends AppliedClusterResourceQuotaListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,AppliedClusterResourceQuota item);
    public A setToItems(int index,AppliedClusterResourceQuota item);
    public A addToItems(AppliedClusterResourceQuota... items);
    public A addAllToItems(Collection<AppliedClusterResourceQuota> items);
    public A removeFromItems(AppliedClusterResourceQuota... items);
    public A removeAllFromItems(Collection<AppliedClusterResourceQuota> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<AppliedClusterResourceQuota> getItems();
    public List<AppliedClusterResourceQuota> buildItems();
    public AppliedClusterResourceQuota buildItem(int index);
    public AppliedClusterResourceQuota buildFirstItem();
    public AppliedClusterResourceQuota buildLastItem();
    public AppliedClusterResourceQuota buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    public A withItems(List<AppliedClusterResourceQuota> items);
    public A withItems(AppliedClusterResourceQuota... items);
    public Boolean hasItems();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> addNewItem();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> addNewItemLike(AppliedClusterResourceQuota item);
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> setNewItemLike(int index,AppliedClusterResourceQuota item);
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editItem(int index);
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editFirstItem();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editLastItem();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AppliedClusterResourceQuotaFluent<AppliedClusterResourceQuotaListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/AppliedClusterResourceQuotaListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface AppliedClusterResourceQuotaListFluent<A extends AppliedClusterResourceQuotaListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,AppliedClusterResourceQuota item);
    public A setToItems(int index,AppliedClusterResourceQuota item);
    public A addToItems(AppliedClusterResourceQuota... items);
    public A addAllToItems(Collection<AppliedClusterResourceQuota> items);
    public A removeFromItems(AppliedClusterResourceQuota... items);
    public A removeAllFromItems(Collection<AppliedClusterResourceQuota> items);
    public A removeMatchingFromItems(Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<AppliedClusterResourceQuota> getItems();
    public List<AppliedClusterResourceQuota> buildItems();
    public AppliedClusterResourceQuota buildItem(int index);
    public AppliedClusterResourceQuota buildFirstItem();
    public AppliedClusterResourceQuota buildLastItem();
    public AppliedClusterResourceQuota buildMatchingItem(Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    public A withItems(List<AppliedClusterResourceQuota> items);
    public A withItems(AppliedClusterResourceQuota... items);
    public Boolean hasItems();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> addNewItem();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> addNewItemLike(AppliedClusterResourceQuota item);
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> setNewItemLike(int index,AppliedClusterResourceQuota item);
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editItem(int index);
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editFirstItem();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editLastItem();
    public AppliedClusterResourceQuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<AppliedClusterResourceQuotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AppliedClusterResourceQuotaFluent<AppliedClusterResourceQuotaListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
